# skill_tree_parser

`技能树解解释器` 是[技能森林](https://gitcode.net/csdn/skill_tree)的一部分，属于 `技能树服务构建部分`。

## 说明

CSDN 技能树结构（章节、元信息、习题）解释器，支持技能树结构和内容的分析、解释。

## what's new

### 0.0.5

- 修正错误的程序流程

### 0.0.4

- 支持在习题中内嵌 markdown 源码

### 0.0.5

- 捕获习题编码错误
- 捕获 json 文件编码错误

### 0.0.6

- 为 `keywords_must` 和 `keywords_forbid` 的读取操作添加默认值

### 0.0.7

- 为 config.json 添加默认的 `keywords_must` 和 `keywords_forbid` 空列表

### 0.0.8

- 补充对 $ 符号的宽容处理

### 0.0.9

- 添加 init 方法

### 0.0.10

- 修复一个在 windows 环境下的安装错误

### 0.0.11

- 增加 group 字段

### 0.0.12

- 增加 FAQ
- 修正 `requirements.txt` 包拼写错误

### 0.0.13

- 增加 subtree 字段

### 0.1.0

- 增加新的习题类型

### 0.1.1

- bug 修复